import * as i0 from '@angular/core';
import { Injector, Directive, Inject, Component, Input, InjectionToken, inject, numberAttribute, forwardRef, ViewChild } from '@angular/core';
import * as i1 from '@angular/forms';
import { Validators, NgControl, FormControlName, FormGroupDirective, NG_VALUE_ACCESSOR, ReactiveFormsModule } from '@angular/forms';
import { Subject, takeUntil, startWith, distinctUntilChanged, tap, debounceTime, map } from 'rxjs';
import { KeyValuePipe, NgClass } from '@angular/common';

class ControlValueAccessorDirective {
    injector;
    control;
    isRequired = false;
    _isDisabled = false;
    _destroy$ = new Subject();
    _onTouched;
    constructor(injector) {
        this.injector = injector;
    }
    ngOnInit() {
        this.setFormControl();
        this.isRequired = this.control?.hasValidator(Validators.required) ?? false;
    }
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
    }
    setFormControl() {
        try {
            const formControl = this.injector.get(NgControl);
            switch (formControl.constructor) {
                case FormControlName:
                    this.control = this.injector
                        .get(FormGroupDirective)
                        .getControl(formControl);
                    break;
                default:
                    this.control = formControl.form;
                    break;
            }
        }
        catch (error) {
            throw error;
        }
    }
    writeValue(obj) {
        if (this.control && this.control.value !== obj) {
            this.control.setValue(obj);
        }
    }
    registerOnChange(fn) {
        this.control?.valueChanges.pipe(takeUntil(this._destroy$), startWith(this.control.value), distinctUntilChanged(), tap((val) => fn(val))).subscribe(() => this.control?.markAsUntouched());
    }
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    setDisabledState(isDisabled) {
        if (this._isDisabled !== isDisabled) {
            this._isDisabled = isDisabled;
            isDisabled ? this.control?.disable() : this.control?.enable();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: ControlValueAccessorDirective, deps: [{ token: Injector }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.7", type: ControlValueAccessorDirective, isStandalone: true, selector: "[libControlValueAccessor]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: ControlValueAccessorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[libControlValueAccessor]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.Injector, decorators: [{
                    type: Inject,
                    args: [Injector]
                }] }] });

class ValidationErrorsComponent {
    errors = {};
    customErrorMessages = {};
    errorMessages = {
        required: 'This field is required',
        minlength: 'This field must be at least {requiredLength} characters long',
        maxlength: 'This field must be at most {requiredLength} characters long',
        pattern: 'This field must contain a correct pattern'
    };
    ngOnChanges(changes) {
        const { customErrorMessages } = changes;
        if (customErrorMessages) {
            this.errorMessages = {
                ...this.errorMessages,
                ...customErrorMessages.currentValue
            };
        }
    }
    getErrorMessage(errorKey, errorValue) {
        const messageTemplate = this.errorMessages[errorKey] || 'Invalid field';
        // Replace placeholders in the message with actual values from the error object
        if (typeof errorValue === 'object' && errorValue !== null) {
            return messageTemplate.replace(/{(\w+)}/g, (_, key) => errorValue[key] || '');
        }
        return messageTemplate;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: ValidationErrorsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.7", type: ValidationErrorsComponent, isStandalone: true, selector: "lib-validation-errors", inputs: { errors: "errors", customErrorMessages: "customErrorMessages" }, usesOnChanges: true, ngImport: i0, template: "<ul class=\"mt-1\">\n  @if (errors) {\n    @for (error of errors | keyvalue; track error.key) {\n      <li class=\"text-sm text-red-400\">\n        {{ getErrorMessage(error.key, error.value) }}\n      </li>\n    }\n  }\n</ul>\n", styles: [""], dependencies: [{ kind: "pipe", type: KeyValuePipe, name: "keyvalue" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: ValidationErrorsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-validation-errors', standalone: true, imports: [
                        KeyValuePipe
                    ], template: "<ul class=\"mt-1\">\n  @if (errors) {\n    @for (error of errors | keyvalue; track error.key) {\n      <li class=\"text-sm text-red-400\">\n        {{ getErrorMessage(error.key, error.value) }}\n      </li>\n    }\n  }\n</ul>\n" }]
        }], propDecorators: { errors: [{
                type: Input
            }], customErrorMessages: [{
                type: Input
            }] } });

/* THEMING CONFIG */
const DEFAULT_THEMING_CONFIG = {
    accentColour: "yellow"
};
const THEMING_CONFIG = new InjectionToken("THEMING_CONFIG", {
    providedIn: 'root',
    factory: () => DEFAULT_THEMING_CONFIG
});

class AutocompleteInputComponent extends ControlValueAccessorDirective {
    inputId = '';
    label = '';
    placeholder = '';
    inputType = 'text';
    autocomplete = 'off';
    customErrorMessages = {};
    options = [];
    numberOfOptionsToShow = 9;
    inputElement;
    isOpen = false;
    selectedIndex = -1;
    filteredOptions = [];
    themingConfig = inject(THEMING_CONFIG);
    ngOnInit() {
        super.ngOnInit();
        this.setupFilter();
        this.filteredOptions = this.options.slice(0, this.numberOfOptionsToShow);
    }
    ngAfterViewInit() {
        this.addThemingClasses();
    }
    onFocus() {
        this.isOpen = true;
    }
    onInput() {
        this.isOpen = true;
    }
    onBlur() {
        setTimeout(() => {
            this.isOpen = false;
        }, 300);
    }
    onKeyDown(event) {
        if (event.key === 'ArrowDown') {
            this.selectedIndex = (this.selectedIndex + 1) % Object.keys(this.filteredOptions).length;
            event.preventDefault();
        }
        else if (event.key === 'ArrowUp') {
            this.selectedIndex = (this.selectedIndex - 1 + Object.keys(this.filteredOptions).length) % Object.keys(this.filteredOptions).length;
            event.preventDefault();
        }
        else if (event.key === 'Enter' && this.selectedIndex >= 0) {
            this.selectOption(this.filteredOptions[this.selectedIndex]);
            event.preventDefault();
        }
    }
    selectOption(option) {
        this.control.setValue(option.value);
        this.isOpen = false;
    }
    focusInputComponent() {
        this.inputElement.nativeElement.focus();
    }
    setupFilter() {
        this.control.valueChanges
            .pipe(debounceTime(300), distinctUntilChanged(), map(value => this.filterOptions(value)))
            .subscribe(filtered => {
            this.selectedIndex = -1;
            this.filteredOptions = filtered.slice(0, this.numberOfOptionsToShow);
        });
    }
    filterOptions(searchTerm) {
        if (!searchTerm) {
            return this.options.slice(0, this.numberOfOptionsToShow);
        }
        const lowerCaseTerm = searchTerm.toLowerCase();
        return this.options.filter(option => option.value.toLowerCase().includes(lowerCaseTerm));
    }
    addThemingClasses() {
        this.inputElement.nativeElement.classList.add(`focus-within:border-${this.themingConfig.accentColour}-500`);
        this.inputElement.nativeElement.classList.add(`focus-within:ring-${this.themingConfig.accentColour}-500`);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: AutocompleteInputComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.7", type: AutocompleteInputComponent, isStandalone: true, selector: "lib-autocomplete-input", inputs: { inputId: "inputId", label: "label", placeholder: "placeholder", inputType: "inputType", autocomplete: "autocomplete", customErrorMessages: "customErrorMessages", options: "options", numberOfOptionsToShow: ["numberOfOptionsToShow", "numberOfOptionsToShow", numberAttribute] }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => AutocompleteInputComponent),
                multi: true
            }
        ], viewQueries: [{ propertyName: "inputElement", first: true, predicate: ["input"], descendants: true }], usesInheritance: true, ngImport: i0, template: "<div class=\"relative block\">\n  @if (control) {\n    <div>\n      <label [for]=\"inputId\" class=\"block text-xs font-medium text-gray-700\"> {{ label }} </label>\n\n      <input #input [type]=\"inputType\" [id]=\"inputId\" [placeholder]=\"placeholder\" [formControl]=\"control\"\n             (focus)=\"onFocus()\" (blur)=\"onBlur()\" (keydown)=\"onKeyDown($event)\" (input)=\"onInput()\"\n             [autocomplete]=\"autocomplete\"\n             class=\"mt-1 w-full rounded-md border-gray-200 shadow-sm sm:text-sm focus-within:ring-1 placeholder:text-zinc-400\"\n             [ngClass]=\"{'focus-within:border-red-400 focus-within:ring-red-400 border-red-400': control.invalid && !control.untouched}\"/>\n\n      @if (control.invalid && !control.untouched) {\n        <lib-validation-errors [errors]=\"control.errors\" [customErrorMessages]=\"customErrorMessages\"/>\n      }\n    </div>\n  }\n\n  @if (isOpen) {\n    <div class=\"absolute inset-x-0 top-16 z-50 rounded-md border border-gray-100 bg-white shadow-lg\">\n      <ul class=\"max-h-96 space-y-1 overflow-auto p-2\">\n        @for (option of filteredOptions; let i = $index; track option.id) {\n          <li [value]=\"option.value\" [ngClass]=\"{'bg-gray-100': i == selectedIndex}\" (click)=\"selectOption(option)\"\n              class=\"flex items-center rounded-md px-4 py-2 text-sm text-gray-700 hover:bg-gray-100 focus:bg-gray-50\">\n            {{ option.value }}\n          </li>\n        } @empty {\n          <p class=\"flex items-center rounded-md px-4 py-2 text-sm font-medium text-gray-700\">No results found</p>\n        }\n      </ul>\n    </div>\n  }\n</div>\n", styles: [""], dependencies: [{ kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "component", type: ValidationErrorsComponent, selector: "lib-validation-errors", inputs: ["errors", "customErrorMessages"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: AutocompleteInputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-autocomplete-input', standalone: true, imports: [
                        NgClass,
                        ValidationErrorsComponent,
                        ReactiveFormsModule
                    ], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => AutocompleteInputComponent),
                            multi: true
                        }
                    ], template: "<div class=\"relative block\">\n  @if (control) {\n    <div>\n      <label [for]=\"inputId\" class=\"block text-xs font-medium text-gray-700\"> {{ label }} </label>\n\n      <input #input [type]=\"inputType\" [id]=\"inputId\" [placeholder]=\"placeholder\" [formControl]=\"control\"\n             (focus)=\"onFocus()\" (blur)=\"onBlur()\" (keydown)=\"onKeyDown($event)\" (input)=\"onInput()\"\n             [autocomplete]=\"autocomplete\"\n             class=\"mt-1 w-full rounded-md border-gray-200 shadow-sm sm:text-sm focus-within:ring-1 placeholder:text-zinc-400\"\n             [ngClass]=\"{'focus-within:border-red-400 focus-within:ring-red-400 border-red-400': control.invalid && !control.untouched}\"/>\n\n      @if (control.invalid && !control.untouched) {\n        <lib-validation-errors [errors]=\"control.errors\" [customErrorMessages]=\"customErrorMessages\"/>\n      }\n    </div>\n  }\n\n  @if (isOpen) {\n    <div class=\"absolute inset-x-0 top-16 z-50 rounded-md border border-gray-100 bg-white shadow-lg\">\n      <ul class=\"max-h-96 space-y-1 overflow-auto p-2\">\n        @for (option of filteredOptions; let i = $index; track option.id) {\n          <li [value]=\"option.value\" [ngClass]=\"{'bg-gray-100': i == selectedIndex}\" (click)=\"selectOption(option)\"\n              class=\"flex items-center rounded-md px-4 py-2 text-sm text-gray-700 hover:bg-gray-100 focus:bg-gray-50\">\n            {{ option.value }}\n          </li>\n        } @empty {\n          <p class=\"flex items-center rounded-md px-4 py-2 text-sm font-medium text-gray-700\">No results found</p>\n        }\n      </ul>\n    </div>\n  }\n</div>\n" }]
        }], propDecorators: { inputId: [{
                type: Input
            }], label: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], inputType: [{
                type: Input
            }], autocomplete: [{
                type: Input
            }], customErrorMessages: [{
                type: Input
            }], options: [{
                type: Input,
                args: [{ required: true }]
            }], numberOfOptionsToShow: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], inputElement: [{
                type: ViewChild,
                args: ['input']
            }] } });

class InputComponent extends ControlValueAccessorDirective {
    inputId = '';
    label = '';
    placeholder = '';
    inputType = 'text';
    autocomplete = 'off';
    customErrorMessages = {};
    inputElement;
    themingConfig = inject(THEMING_CONFIG);
    ngAfterViewInit() {
        this.addThemingClasses();
    }
    focusInputComponent() {
        this.inputElement.nativeElement.focus();
    }
    addThemingClasses() {
        this.inputElement.nativeElement.classList.add(`focus-within:border-${this.themingConfig.accentColour}-500`);
        this.inputElement.nativeElement.classList.add(`focus-within:ring-${this.themingConfig.accentColour}-500`);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: InputComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.7", type: InputComponent, isStandalone: true, selector: "lib-input", inputs: { inputId: "inputId", label: "label", placeholder: "placeholder", inputType: "inputType", autocomplete: "autocomplete", customErrorMessages: "customErrorMessages" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => InputComponent),
                multi: true
            }
        ], viewQueries: [{ propertyName: "inputElement", first: true, predicate: ["input"], descendants: true }], usesInheritance: true, ngImport: i0, template: "@if (control) {\n  <div>\n    <label [for]=\"inputId\" class=\"block text-xs font-medium text-gray-700\"> {{ label }} </label>\n\n    <input #input [type]=\"inputType\" [id]=\"inputId\" [placeholder]=\"placeholder\" [formControl]=\"control\"\n           [autocomplete]=\"autocomplete\"\n           class=\"mt-1 w-full rounded-md border-gray-200 shadow-sm sm:text-sm focus-within:ring-1 placeholder:text-zinc-400\"\n           [ngClass]=\"{'focus-within:border-red-400 focus-within:ring-red-400 border-red-400': control.invalid && !control.untouched}\"/>\n\n    @if (control.invalid && !control.untouched) {\n      <lib-validation-errors [errors]=\"control.errors\" [customErrorMessages]=\"customErrorMessages\"/>\n    }\n  </div>\n}\n", styles: [""], dependencies: [{ kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: ValidationErrorsComponent, selector: "lib-validation-errors", inputs: ["errors", "customErrorMessages"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: InputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-input', standalone: true, imports: [
                        NgClass,
                        ReactiveFormsModule,
                        ValidationErrorsComponent
                    ], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => InputComponent),
                            multi: true
                        }
                    ], template: "@if (control) {\n  <div>\n    <label [for]=\"inputId\" class=\"block text-xs font-medium text-gray-700\"> {{ label }} </label>\n\n    <input #input [type]=\"inputType\" [id]=\"inputId\" [placeholder]=\"placeholder\" [formControl]=\"control\"\n           [autocomplete]=\"autocomplete\"\n           class=\"mt-1 w-full rounded-md border-gray-200 shadow-sm sm:text-sm focus-within:ring-1 placeholder:text-zinc-400\"\n           [ngClass]=\"{'focus-within:border-red-400 focus-within:ring-red-400 border-red-400': control.invalid && !control.untouched}\"/>\n\n    @if (control.invalid && !control.untouched) {\n      <lib-validation-errors [errors]=\"control.errors\" [customErrorMessages]=\"customErrorMessages\"/>\n    }\n  </div>\n}\n" }]
        }], propDecorators: { inputId: [{
                type: Input,
                args: [{ required: true }]
            }], label: [{
                type: Input,
                args: [{ required: true }]
            }], placeholder: [{
                type: Input
            }], inputType: [{
                type: Input
            }], autocomplete: [{
                type: Input
            }], customErrorMessages: [{
                type: Input
            }], inputElement: [{
                type: ViewChild,
                args: ['input']
            }] } });

class SelectComponent extends ControlValueAccessorDirective {
    inputId = '';
    label = '';
    autocomplete = 'off';
    options = [];
    customErrorMessages = {};
    selectElement;
    themingConfig = inject(THEMING_CONFIG);
    ngAfterViewInit() {
        this.addThemingClasses();
    }
    focusSelectComponent() {
        this.selectElement.nativeElement.focus();
    }
    addThemingClasses() {
        this.selectElement.nativeElement.classList.add(`focus-within:border-${this.themingConfig.accentColour}-500`);
        this.selectElement.nativeElement.classList.add(`focus-within:ring-${this.themingConfig.accentColour}-500`);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: SelectComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.7", type: SelectComponent, isStandalone: true, selector: "lib-select", inputs: { inputId: "inputId", label: "label", autocomplete: "autocomplete", options: "options", customErrorMessages: "customErrorMessages" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => SelectComponent),
                multi: true
            }
        ], viewQueries: [{ propertyName: "selectElement", first: true, predicate: ["select"], descendants: true }], usesInheritance: true, ngImport: i0, template: "@if (control) {\n  <div>\n    <label [for]=\"inputId\" class=\"block text-xs font-medium text-gray-700\"> {{ label }} </label>\n\n    <select #select [formControl]=\"control\" [id]=\"inputId\"\n            class=\"mt-1 w-full rounded-md border-gray-200 shadow-sm sm:text-sm focus-within:ring-1\">\n      <option value=\"\" class=\"text-zinc-400\" disabled selected>Please select</option>\n      @for (option of options; track option.id) {\n        <option [value]=\"option.value\">{{ option.value }}</option>\n      }\n    </select>\n\n    @if (control.invalid && !control.untouched) {\n      <lib-validation-errors [errors]=\"control.errors\" [customErrorMessages]=\"customErrorMessages\"/>\n    }\n  </div>\n}\n", styles: [""], dependencies: [{ kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: ValidationErrorsComponent, selector: "lib-validation-errors", inputs: ["errors", "customErrorMessages"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: SelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-select', standalone: true, imports: [
                        ReactiveFormsModule,
                        ValidationErrorsComponent
                    ], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => SelectComponent),
                            multi: true
                        }
                    ], template: "@if (control) {\n  <div>\n    <label [for]=\"inputId\" class=\"block text-xs font-medium text-gray-700\"> {{ label }} </label>\n\n    <select #select [formControl]=\"control\" [id]=\"inputId\"\n            class=\"mt-1 w-full rounded-md border-gray-200 shadow-sm sm:text-sm focus-within:ring-1\">\n      <option value=\"\" class=\"text-zinc-400\" disabled selected>Please select</option>\n      @for (option of options; track option.id) {\n        <option [value]=\"option.value\">{{ option.value }}</option>\n      }\n    </select>\n\n    @if (control.invalid && !control.untouched) {\n      <lib-validation-errors [errors]=\"control.errors\" [customErrorMessages]=\"customErrorMessages\"/>\n    }\n  </div>\n}\n" }]
        }], propDecorators: { inputId: [{
                type: Input
            }], label: [{
                type: Input
            }], autocomplete: [{
                type: Input
            }], options: [{
                type: Input,
                args: [{ required: true }]
            }], customErrorMessages: [{
                type: Input
            }], selectElement: [{
                type: ViewChild,
                args: ['select']
            }] } });

class ButtonComponent {
    label = 'Submit';
    type = 'button';
    disabled = false;
    inverted = false;
    buttonElement;
    themingConfig = inject(THEMING_CONFIG);
    ngAfterViewInit() {
        this.addThemingClasses();
    }
    addThemingClasses() {
        if (!this.inverted) {
            this.buttonElement.nativeElement.classList.add(`border-${this.themingConfig.accentColour}-600`);
            this.buttonElement.nativeElement.classList.add(`bg-${this.themingConfig.accentColour}-600`);
            this.buttonElement.nativeElement.classList.add(`hover:text-${this.themingConfig.accentColour}-600`);
            this.buttonElement.nativeElement.classList.add(`active:text-${this.themingConfig.accentColour}-500`);
        }
        else {
            this.buttonElement.nativeElement.classList.add(`border-${this.themingConfig.accentColour}-600`);
            this.buttonElement.nativeElement.classList.add(`text-${this.themingConfig.accentColour}-600`);
            this.buttonElement.nativeElement.classList.add(`hover:bg-${this.themingConfig.accentColour}-600`);
            this.buttonElement.nativeElement.classList.add(`active:bg-${this.themingConfig.accentColour}-500`);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: ButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.7", type: ButtonComponent, isStandalone: true, selector: "lib-button", inputs: { label: "label", type: "type", disabled: "disabled", inverted: "inverted" }, viewQueries: [{ propertyName: "buttonElement", first: true, predicate: ["button"], descendants: true }], ngImport: i0, template: "<button #button [disabled]=\"disabled\" [ngClass]=\"{'text-white hover:bg-transparent disabled:bg-gray-300': !inverted, 'hover:text-white disabled:bg-white': inverted}\"\n        [type]=\"type\"\n        class=\"inline-block rounded border px-12 py-3 text-sm text-center font-medium focus:outline-none focus:ring disabled:text-gray-500 disabled:border-gray-300 cursor-pointer\">\n  {{ label }}\n</button>\n", styles: [""], dependencies: [{ kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: ButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-button', standalone: true, imports: [
                        NgClass
                    ], template: "<button #button [disabled]=\"disabled\" [ngClass]=\"{'text-white hover:bg-transparent disabled:bg-gray-300': !inverted, 'hover:text-white disabled:bg-white': inverted}\"\n        [type]=\"type\"\n        class=\"inline-block rounded border px-12 py-3 text-sm text-center font-medium focus:outline-none focus:ring disabled:text-gray-500 disabled:border-gray-300 cursor-pointer\">\n  {{ label }}\n</button>\n" }]
        }], propDecorators: { label: [{
                type: Input
            }], type: [{
                type: Input
            }], disabled: [{
                type: Input
            }], inverted: [{
                type: Input
            }], buttonElement: [{
                type: ViewChild,
                args: ['button']
            }] } });

class TitleComponent {
    title = 'Title';
    titleDivider;
    themingConfig = inject(THEMING_CONFIG);
    ngAfterViewInit() {
        this.addThemingClasses();
    }
    addThemingClasses() {
        this.titleDivider.nativeElement.classList.add(`bg-${this.themingConfig.accentColour}-400`);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: TitleComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.7", type: TitleComponent, isStandalone: true, selector: "lib-title", inputs: { title: "title" }, viewQueries: [{ propertyName: "titleDivider", first: true, predicate: ["titleDivider"], descendants: true }], ngImport: i0, template: "<div>\n  <h1 class=\"text-4xl font-bold mb-4\">{{ title }}</h1>\n  <div #titleDivider class=\"w-20 h-1\"></div>\n</div>\n", styles: [""] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.7", ngImport: i0, type: TitleComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-title', standalone: true, imports: [], template: "<div>\n  <h1 class=\"text-4xl font-bold mb-4\">{{ title }}</h1>\n  <div #titleDivider class=\"w-20 h-1\"></div>\n</div>\n" }]
        }], propDecorators: { title: [{
                type: Input,
                args: [{ required: true }]
            }], titleDivider: [{
                type: ViewChild,
                args: ['titleDivider']
            }] } });

/*
 * Public API Surface of easypost-angular-toolkit
 */
/* COMPONENTS */

/**
 * Generated bundle index. Do not edit.
 */

export { AutocompleteInputComponent, ButtonComponent, InputComponent, SelectComponent, THEMING_CONFIG, TitleComponent };
//# sourceMappingURL=easypost-angular-toolkit.mjs.map
